@@ -449,6 +449,28 @@ heat-translator/master/translator/tests/data/custom_types/wordpress.yaml
         self.assertTrue(custom_defs.get("mycompany.tosca.nodes."
                                         "WebApplication.WordPress"))
 
+    def test_imports_with_local_defs(self):
+        """Compare custom types on local and remote."""
+
+        ctypes = {
+            "remote": ("https://raw.githubusercontent.com/openstack/"
+                       "heat-translator/master/translator/tests/data/"
+                       "custom_types/wordpress.yaml"),
+            "local": "../data/wordpress.yaml"}
+
+        tpl_snippet = '''
+        imports:
+        - {}
+        '''.format(ctypes["remote"])
+        local_defs = {ctypes["remote"]: ctypes["local"]}
+
+        path = 'toscaparser/tests/data/tosca_elk.yaml'
+        imports = (toscaparser.utils.yamlparser.
+                   simple_parse(tpl_snippet)['imports'])
+        ld1 = ImportsLoader(imports, path, "node_types")
+        ld2 = ImportsLoader(imports, path, "node_types", local_defs)
+        self.assertEqual(ld1.get_custom_defs(), ld2.get_custom_defs())
+
     def test_imports_file_with_suffix_yml(self):
         tpl_snippet = '''
         imports:
